==> v0.4.9.zip: libarea/app/Languages/zh_CN/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => '更多',
    'category'          => '类别',
    'categories'        => '类别',
    'audits'            => '审核',
    'soft'              => '软件',
    'website'           => '网站',
    'websites'          => '站点',
    'on_website'        => '转到网站',
    'deleted'           => '已删除',
    'facets'            => '部分',
    'favorites'         => '书签',
    'menu'              => '菜单',
    'no'                => '否',
    'yes'               => '是',
    'title'             => '标题',
    'description'       => '描述',
    'catalog'           => '目录',
    'find'              => '寻找',
    'help'              => '提示',
    'deny_replies'      => '拒绝回复？',
    'posted'            => '已发布？',
    'necessarily'       => '必填',
    'status'            => '链接状态',
    'there_program'     => '有一个项目？',
    'there_forum'       => '该网站有一个论坛？',
    'there_portal'      => '这是传送门吗？',
    'there_blog'        => '这是个人博客吗？',
    'there_reference'   => '这是一个参考网站（百科全书）吗？',
    'hosted_github'     => '程序托管在GitHub上？',
    'url_github'        => 'GitHub存储库URL',
    'related_posts'     => '相关帖子',
    'desc_.formed'       => '描述已形成',
    'by_date'           => '按日期',
    'top_view'          => '按评分',
    'new_sites'         => '新网站',
    'audits_view'       => '需要考虑',
    'deleted_view'      => '已删除',
    'my_website'        => '我的网站',
    'no_website'        => '目前还没有网站',
    'bookmarks'         => '我的网站书签',
    'bookmarks_view'    => '我的书签',
    'no_bookmarks'      => '还没有书签',
    'answers'           => '答复',
    'no_answers'        => '目前还没有答复...',
    'characters'        => '字符',
    'remove'            => '删除',
    'reply'             => '回复',
    'edit'              => '编辑',
    'cancel'            => '取消',
    'add'               => '添加',
    'markdown'          => '降價標記',
    'recommended'       => '推荐',
    'my_website_info'   => '我添加的网站列表',
    'moderation'        => '适度',
    'sign_in'           => '登录',
    'registration'      => '注册',
    'site_added'        => '已添加網站',

    'closed'            => '禁止讨论该网站。作者或工作人员不公开讨论。',
 
    'audits_home_title' => '网站审核',
    'audits_home_desc'  => '正在考虑的网站',
    'num_website'       => ['网站', '网站', '网站'],
    
    'news'              => '新闻媒体',
    'internet'          => '互联网',
    'culture'           => '文化艺术',
    'software'          => '程序软件',
    'reference_info'    => '参考资料',
    'reference_help'    => '百科全书、参考书籍',
    'science'           => '科学教育',
    'goods'             => '商品服务',
    'life'              => '生活家居',
    'cms'               => 'CMS系统',
    'life_help'         => '儿童、动物、爱好...',
    'security'          => '安全...',
    'society'           => '社会与政治',
    
    'string_length'         => '长度不正确 {name}',
    'website_correctness'   => '网站地址（URL）不正确',
    'site_replay'           => '此网站已存在系统中',

    'data_help'         => '<i class="gray-600">标题格式:</i><br> «LibArea» — 社区<br><br><i class="gray-600">描述(无广告):</i><br> ...网站上有什么？<i>',
    
    'add_category'      => '添加类别',
    'add_website'       => '添加网站',
    'edit_website'      => '编辑网站',
    
    'sidebar_info'      => '按主题标题系统化的网站目录。',
    'banner_info'       => '带注释和截图的网站目录。分面评分，搜索。可以为网站、程序、评级投票的资源上的书签',
    
    'main_title'         => '网站目录',
    'main_desc'          => '目录中的站点列表按时间顺序排列。能够搜索、添加书签、按受欢迎程度排序',
    
    'deleted_title'     => '远程站点',
    'deleted_desc'      => '...',
    'audits_title'      => '站点审核',
    'audits_desc'       => '...',
    
    'all'               => '全部',
    'github'            => 'GitHub',
    'forum'             => '论坛',
    'blog'              => '博客',
    'portal'            => '门户网站',
    'reference'         => '百科全书',
    
    'top_title'         => '{name} -按受欢迎程度',
    'top_desc'          => '按主题公布的网站列表 {description_info}',
    'all_title'         => '{name} -专栏，按日期划分的网站',
    'all_desc'          => '专栏中按时间顺序排列的网站 {description_info}',
];

==> v0.5.7.zip: libarea/app/Languages/zh_CN/web.php <==
<?php

/*
* The following language strings are used by the site directory.
*
* Следующие языковые строки используются Каталога сайтов.
*/

return [
    'more'              => '更多',
    'category'          => '类别',
    'categories'        => '类别',
    'audits'            => '审核',
    'soft'              => '软件',
    'website'           => '网站',
    'websites'          => '站点',
    'comments'          => '评论',
    'on_website'        => '转到网站',
    'deleted'           => '已删除',
    'facets'            => '部分',
    'favorites'         => '书签',
    'menu'              => '菜单',
    'no'                => '否',
    'yes'               => '是',
    'title'             => '标题',
    'description'       => '描述',
    'catalog'           => '目录',
    'find'              => '寻找',
    'help'              => '提示',
    'deny_replies'      => '拒绝回复？',
    'posted'            => '已发布？',
    'necessarily'       => '必填',
    'status'            => '链接状态',
    'refresh'           => '刷新',
    'there_program'     => '有一个项目？',
    'there_forum'       => '该网站有一个论坛？',
    'there_portal'      => '这是传送门吗？',
    'there_blog'        => '这是个人博客吗？',
    'there_reference'   => '这是一个参考网站（百科全书）吗？',
    'there_goods'       => '该网站是否提供产品和服务？',
    'hosted_github'     => '程序托管在GitHub上？',
    'url_github'        => 'GitHub存储库URL',
    'related_posts'     => '相关帖子',
    'desc_.formed'       => '描述已形成',
    'by_date'           => '按日期',
    'top'               => '最佳',
    'top_view'          => '按评分',
    'new_sites'         => '新网站',
    'audits_view'       => '需要考虑',
    'deleted_view'      => '已删除',
    'my_website'        => '我的网站',
    'no_website'        => '目前还没有网站',
    'bookmarks'         => '我的网站书签',
    'bookmarks_view'    => '我的书签',
    'no_bookmarks'      => '还没有书签',
    'answers'           => '答复',
    'no_answers'        => '目前还没有答复...',
    'characters'        => '字符',
    'remove'            => '删除',
    'reply'             => '回复',
    'edit'              => '编辑',
    'cancel'            => '取消',
    'add'               => '添加',
    'markdown'          => '降價標記',
    'recommended'       => '推荐',
    'my_website_info'   => '我添加的网站列表',
    'moderation'        => '适度',
    'sign_in'           => '登录',
    'registration'      => '注册',
    'site_added'        => '已添加網站',

    'closed'            => '禁止讨论该网站。作者或工作人员不公开讨论。',

    'screenshot_time'   => '截屏可能需要一些時間。',
 
    'audits_home_title' => '网站审核',
    'audits_home_desc'  => '正在考虑的网站',
    'num_website'       => ['网站', '网站', '网站'],
    
    'news'              => '新闻媒体',
    'internet'          => '互联网',
    'culture'           => '文化艺术',
    'software'          => '程序软件',
    'reference_info'    => '参考资料',
    'reference_help'    => '百科全书、参考书籍',
    'science'           => '科学教育',
    'business'          => '商业',
    'life'              => '生活家居',
    'cms'               => 'CMS系统',
    'life_help'         => '儿童、动物、爱好...',
    'security'          => '安全...',
    'society'           => '社会与政治',

    'contact_information'   => '联系信息',
    'telephone'             => '电话',
    'email'                 => 'Email',
    'vk'                    => 'VKontakte (URL)',
    'telegram'              => 'Telegram (URL)',

    'string_length'         => '长度不正确 {name}',
    'website_correctness'   => '网站地址（URL）不正确',
    'site_replay'           => '此网站已存在系统中',

    'data_help'         => '<i class="gray-600">标题格式:</i><br> «LibArea» — 社区<br><br><i class="gray-600">描述(无广告):</i><br> ...网站上有什么？',
    'admin_help'         => '僅對員工開放的封閉部分',
    
    'add_category'      => '添加类别',
    'add_website'       => '添加网站',
    'edit_website'      => '编辑网站',
    
    'sidebar_info'      => '按主题标题系统化的网站目录。',
    'banner_info'       => '带注释和截图的网站目录。分面评分，搜索。可以为网站、程序、评级投票的资源上的书签',
    
    'main_title'        => '网站目录',
    'main_desc'         => '目录中的站点列表按时间顺序排列。能够搜索、添加书签、按受欢迎程度排序',
    
    'deleted_title'     => '远程站点',
    'audits_title'      => '站点审核',
    
    'all'               => '全部',
    'github'            => 'GitHub',
    'forum'             => '论坛',
    'blog'              => '博客',
    'portal'            => '门户网站',
    'reference'         => '百科全书',
    'goods'             => '商品服务',
    
    'top_title'         => '{name} -按受欢迎程度',
    'top_desc'          => '按主题公布的网站列表 {description_info}',
    'all_title'         => '{name} -专栏，按日期划分的网站',
    'all_desc'          => '专栏中按时间顺序排列的网站 {description_info}',
];
